** Create dataset for summary figure

** Get index data
	use "$merged_data/endline_indices.dta", clear
	
	keep child_id dise stratafixed* treat el_index_dropout el_index_marriage el_child_labor

	tempfile indexes
	save `indexes'
	
** Get question data
	use "$merged_data/nine_skills.dta", clear
	
	keep child_id dise q505f_talkpartns_whnimarry qq515a_girlsnt_highedu_flip a424g_freedom_boy_ q511a_b
	
	merge 1:1 child_id using `indexes'
	drop _merge
	
	label var q511a_b "Has a goal for next week"
	
	**Can talk to parents about marriage (Empowerment): q505f_talkpartns_whnimarry
	
	**Girls should have the same freedom as boys  (Gender Norms): a424g_freedom_boy_
	
	**Has a goal for next week (Future Planning): q511a_b
	
	save "$merged_data/summary_figure.dta", replace 
	
	#delimit;
	
	
	use "$merged_data/summary_figure.dta", clear;
	summ;

	local index=1;
	g var=" ";
	g outcome=.;
	g beta=.;
	g se=.;
	g y1=.;
	g y0=.;
	
	foreach var of varlist el_index_dropout q511a_b q505f_talkpartns_whnimarry qq515a_girlsnt_highedu_flip 
	el_child_labor {;
	replace var="`var'" in `index';
	replace outcome=`index' in `index';
	reg `var' treat stratafixed1 stratafixed2, cl(dise);
	replace beta=_b[treat] in `index';
	replace se=_se[treat] in `index';
	tempvar ph;
	predict `ph' if `var'~=.;
	summ `ph' if treat==1 & `var'~=.;
	replace y1=_result(3) in `index';
	summ `ph' if treat==0 & `var'~=.;
	replace y0=_result(3) in `index';
	local index=`index'+1;
	};
	
	drop if outcome==.;
	keep var-y0;
	reshape long y, i(var outcome beta se) j(treat);
	
	g hiy=y+1.96*se if treat==1;
	g loy=y-1.96*se if treat==1;
	
	local outcome=1;
	g outcomegroup = 1 if outcome==1 & treat==0;
	replace outcomegroup=2 if outcome==1 & treat==1;
	local n=4;
	forvalues i=2/5 {;
	replace outcomegroup=`n' if outcome==`i' & treat==0;
	local n=`n'+1;
	replace outcomegroup=`n' if outcome==`i' & treat==1;
	local n=`n'+2;
	};
	
	replace y=y*100;
	replace hiy=hiy*100; replace loy=loy*100;
	label var outcomegroup " ";
	graph twoway (bar y outcomegroup if outcome==1)
	(bar y outcomegroup if outcome==2)
	(bar y outcomegroup if outcome==3)
	(bar y outcomegroup if outcome==4)
	(bar y outcomegroup if outcome==5)
	(rcap hiy loy outcomegroup,
	plotregion(style(none))
	legend(off)
	xlabel(2 "Dropout" 5 "Future Planning (Has a Goal for Next Week)" 8 " Empowerment (Can Talk with Parents about Marriage)"
	11 "Gender Norms (Girls should get Higher Ed)" 14 "Child Labor", noticks angle(15))
	xtitle("") ytitle("Percentage of Sample")
	);
	
	graph export "$figures/figure1.tif", replace;

