** Make treatment graphs

	use "$merged_data/endline_indices", clear
	
	** Define lists of variables for each of the figures
	
	global table5_fig el_index_dropout el_index_grade el_school_attend el_school_dummy
	global table6_2_fig el_index_socioemotional el_index_movement1 el_index_empowerment el_index_selfesteem el_index_planning el_index_marr_expect el_index_employ el_index_gender el_index_enumerator
	global table6_3_fig el_index_p_strengths el_index_p_efficacy el_index_p_movement1 el_index_p_communication el_index_p_gender el_index_p_schooling el_index_p_marriage el_index_locus_control el_index_stress el_index_rosenberg
	global table7_fig_1 el_work_child el_work_pay el_work_nonfamily el_child_labor el_hazardous_labor el_otherworst_labor
	global table7_fig_2 el_hours_worked el_hours_unpd_hhser el_hours_active el_hours_outside
	global table8_fig el_mathproficiency el_hindiproficiency el_englishproficiency
	
	global nocontrols treat stratafixed*, cl(dise) 

	tempfile indices
	save `indices'
	
	
	***** Make figures *****
	
	** Table 5
	
	local line=1
	local sel=`line'+1
	g Xvar=" "
	g Xorder=.
	g Xb=.
	g Xse=.
	
	foreach var of varlist $table5_fig {
		reg `var' $nocontrols
	
		replace Xvar="`var'" in `line'
		replace Xorder=`line' in `line'
		replace Xb=_b[treat] in `line'
		replace Xse=_se[treat] in `line'

		local line=`line'+1
	}
	
	keep Xvar-Xse
	drop if Xb==.

	*make confidence intervals

	g min=Xb-1.96*Xse
	g max=Xb+1.96*Xse

	foreach var of varlist Xb min max {
	replace `var'=`var'*100
	}
	
	#delimit;

	sort Xb; 
	gen size_order = _n;
	label var size_order " ";
	twoway (rcap min max size_order, horizontal 
	ylabel( 1 "Child Has Dropped Out"
	2 "Attended School in Past Week"
	3 "Attendance Rate in Past Week"
	4 "Child Progressed to 7th Grade"
	
	, angle(0))
	ysize(2)
	xlabel(-10(2.5)10)
	) 
	(scatter size_order Xb, msize(medium)  xline(0) xtitle("Percentage Points") plotregion(style(none)) legend(off) graphregion(color(white)));

	graph export "$figures/figure6.tif", replace;

	#delimit cr
	
	** Table 6-2
	
	use "`indices'", clear
	
	local line=1
	local sel=`line'+1
	g Xvar=" "
	g Xorder=.
	g Xb=.
	g Xse=.
	
	foreach var of varlist $table6_2_fig {
		reg `var' $nocontrols
	
		replace Xvar="`var'" in `line'
		replace Xorder=`line' in `line'
		replace Xb=_b[treat] in `line'
		replace Xse=_se[treat] in `line'

		local line=`line'+1
	}
	
	keep Xvar-Xse
	drop if Xb==.

	*make confidence intervals

	g min=Xb-1.96*Xse
	g max=Xb+1.96*Xse


	#delimit;

	sort Xb; 
	gen size_order = _n;
	label var size_order " ";
	twoway (rcap min max size_order, horizontal 
	ylabel( 1 "Marriage Expectations"
	2 "Employment Expectations"
	3 "Freedom of Movement"
	4 "Self-Esteem"
	5 "Socio-Emotional Skills"
	6 "Future Planning"
	7 "Enumerator Assessment"
	8 "Gender Norms Views"
	9 "Empowerment"
	, angle(0))
	ysize(2)
	xlabel(-0.6(0.05)0.2)
	) 
	(scatter size_order Xb, msize(medium)  xline(0) xtitle("Standard Deviations") plotregion(style(none)) legend(off) graphregion(color(white)));

	graph export "$figures/figure7.tif", replace;
	
	#delimit cr
	
	*** Table 6-3
	
	use "`indices'", clear
	
	local line=1
	local sel=`line'+1
	g Xvar=" "
	g Xorder=.
	g Xb=.
	g Xse=.
	

	foreach var of varlist $table6_3_fig {
		reg `var' $nocontrols
	
		replace Xvar="`var'" in `line'
		replace Xorder=`line' in `line'
		replace Xb=_b[treat] in `line'
		replace Xse=_se[treat] in `line'

		local line=`line'+1
	}
	
	keep Xvar-Xse
	drop if Xb==.

	*make confidence intervals

	g min=Xb-1.96*Xse
	g max=Xb+1.96*Xse

	#delimit;
	
	sort Xb; 
	gen size_order = _n;
	
	label var size_order " ";
	
	twoway (rcap min max size_order, horizontal 
	ylabel( 1 "Parental Perceptions of Girl Strengths"
	2 "Perceived Stress"
	3 "Locus of Control"
	4 "Parent-daughter communication "
	5 "Parental Gender Attitudes "
	6 "Parental Perception of Girl Self-Efficacy"
	7 "Rosenberg Self-Esteem "
	8 "Parental Perception of Freedom of Movement"
	9 "Parental Marriage Attitudes"
	10 "Parental Schooling Attitudes"
	, angle(0))
	ysize(2)
	xlabel(-0.125(0.025)0.125)
	) 
	(scatter size_order Xb, 
	msize(medium)  xline(0) xtitle("Standard Deviations") plotregion(style(none)) legend(off) graphregion(color(white)));

	graph export "$figures/figure8.tif", replace;
	
	#delimit cr
	
		*** Table 7
	
	use "`indices'", clear
	
	local line=1
	local sel=`line'+1
	g Xvar=" "
	g Xorder=.
	g Xb=.
	g Xse=.
	
	foreach var of varlist $table7_fig_1 {
		reg `var' $nocontrols
	
		replace Xvar="`var'" in `line'
		replace Xorder=`line' in `line'
		replace Xb=_b[treat] in `line'
		replace Xse=_se[treat] in `line'

		local line=`line'+1
	}
	
	keep Xvar-Xse
	drop if Xb==.

	*make confidence intervals

	g min=Xb-1.96*Xse
	g max=Xb+1.96*Xse

	foreach var of varlist Xb min max {
	replace `var'=`var'*100
	}

	#delimit;

	sort Xb; 
	gen size_order = _n;
	label var size_order " ";
	twoway (rcap min max size_order, horizontal 
	ylabel( 1 "Child Works Outside of Family"
	2 "Child Labor"
	3 "Hazardous Child Labor"
	4 "Other Worst Forms of Child Labor"
	5 "Child Works for Pay"
	6 "Child Works (Economically Active)"

	, angle(0))
	ysize(2)
	xlabel(-15(2.5)15)
	) 
	(scatter size_order Xb, msize(medium)  xline(0) xtitle("Percentage Points") plotregion(style(none)) legend(off) graphregion(color(white)));

	graph export "$figures/figure9.tif", replace;
	
	#delimit cr
	
	*** Table 7-2
	
	use "`indices'", clear
	
	local line=1
	local sel=`line'+1
	g Xvar=" "
	g Xorder=.
	g Xb=.
	g Xse=.
	
	foreach var of varlist $table7_fig_2 {
		reg `var' $nocontrols
	
		replace Xvar="`var'" in `line'
		replace Xorder=`line' in `line'
		replace Xb=_b[treat] in `line'
		replace Xse=_se[treat] in `line'

		local line=`line'+1
	}
	
	keep Xvar-Xse
	drop if Xb==.

	*make confidence intervals

	g min=Xb-1.96*Xse
	g max=Xb+1.96*Xse


	#delimit;
	

	sort Xb; 
	gen size_order = _n;
	label var size_order " ";
	twoway (rcap min max size_order, horizontal 
	ylabel( 1 "Hours Active Outside House"
	2 "Hours in Unpaid Household Services"
	3 "Hours Working (Economically Active)"
	4 "Total Hours (Working & Unpaid)"

	, angle(0))
	ysize(2)
	xlabel(-0.30(0.05)0.45)
	) 
	(scatter size_order Xb, msize(medium)  xline(0) xtitle("Hours in a Typical Day Last Week") plotregion(style(none)) legend(off) graphregion(color(white)));

	graph export "$figures/figure10.tif", replace;
	
	#delimit cr
	
	*** Table 7
	
	use "`indices'", clear
	
	local line=1
	local sel=`line'+1
	g Xvar=" "
	g Xorder=.
	g Xb=.
	g Xse=.
	
	foreach var of varlist $table8_fig {
		reg `var' $nocontrols
	
		replace Xvar="`var'" in `line'
		replace Xorder=`line' in `line'
		replace Xb=_b[treat] in `line'
		replace Xse=_se[treat] in `line'

		local line=`line'+1
	}
	
	keep Xvar-Xse
	drop if Xb==.

	*make confidence intervals

	g min=Xb-1.96*Xse
	g max=Xb+1.96*Xse

	foreach var of varlist Xb min max {
	replace `var'=`var'*100
	}

	#delimit;
	*new i is a numberic value telling us what regression the beta and se came from;
	*I'm going to label it so I can tell which is which - this would be your variable names;

	sort Xb; 
	gen size_order = _n;
	label var size_order " ";
	twoway (rcap min max size_order, horizontal 
	ylabel( 1 "ASER Score - English"
	2 "ASER Score - Mathematics"
	3 "ASER Score- Hindi"

	, angle(0))
	ysize(2)
	xlabel(-25(5)25)
	) 
	(scatter size_order Xb, msize(medium)  xline(0) xtitle("ASER Score") plotregion(style(none)) legend(off) graphregion(color(white)));

	graph export "$figures/figure11.tif", replace;
	
	#delimit cr
	
