** Lifeskills questions, with merged data

* Recode variables as needed
	
	use "$merged_data/ehc_combined.dta",clear
	
	
	**************** Child question measures *****************************

	** Avoiding having to specify missing type
	** Making all that are currently marked as .n or .d as .
	ds, has(type numeric)
	foreach v in `r(varlist)' {
	replace `v' = . if `v'==.n
	replace `v' = . if `v'==.d

	}

	gen q501a_dum = (q501a_gdfrnds >=3) if q501a_gdfrnds!= . 
	// mean close to .5
	
	** Group 502: "Usually or always"
	gen q502a_talk_dum = (q502a_havesmeone_talk >=4) if q502a_havesmeone_talk!= . 
	gen q502b_share_dum = (q502b_smone_shareaccomp >=4) if q502b_smone_shareaccomp!= . 
	gen q502c_help_dum = (q502c_help_advce >=4) if q502c_help_advce!= .
	

	// 503: a are binary
	
	** Create groupings for 503b:
	
	forval num  = 1/9 {
	gen q503b_a`num'= (q503b_goalone_withsmone_`num' == 1) if q503b_goalone_withsmone_`num' != .
	gen q503b_b`num'= (q503b_goalone_withsmone_`num' != 2) if q503b_goalone_withsmone_`num' != .
	}
	
	// a = alone
	// b = alone / sometimes alone, sometimes with someone
	
	** Groupings for 503c:
	
	forval num  = 1/9 {
	gen q503c_a`num'= (q503c_whnvisit_place_`num' == 1) if q503c_whnvisit_place_`num' != .
	gen q503c_b`num'= (q503c_whnvisit_place_`num' == 1 | q503c_whnvisit_place_`num' == 3) if q503c_whnvisit_place_`num' != .

	}
	
	// a = alone
	// b = alone / sometimes alone, sometimes with someone
	// c = allowed to go at all
	
	** Groupings for 504:
	
	foreach var of varlist q504a q504b q504c q504d q504e q504f q504g q504h q504i q504j q504k{
	gen q`var'_a = (`var' == 1) if `var' != .
	gen q`var'_b = (`var' != 3) if `var' != .
	}

	gen q504_areu_currmarrd_flip = (q504_areu_currmarrd == 0) if q504_areu_currmarrd!= .
	
	// a = I do
	// b = I do or I do jointly with relatives
	
	** Flip 505a and b
	
	gen flip_q505a_perm_visitfrnd = 1 + q505a_perm_visitfrnd
	replace flip_q505a_perm_visitfrnd = 0 if flip_q505a_perm_visitfrnd == 2
	
	gen flip_q505b_perm_spnd5_15rs = 1 + q505b_perm_spnd5_15rs
	replace flip_q505b_perm_spnd5_15rs = 0 if flip_q505b_perm_spnd5_15rs == 2
	
	global q505_incl flip_q505a_perm_visitfrnd flip_q505b_perm_spnd5_15rs q505c_ichse_clthswear q505d_talkparnts_schlng q505e_talkparnts_whomarry q505f_talkpartns_whnimarry q505g_typwrk_wntdo_futre q505h_talkprnts_prbwthfrnds

	** 507: making "don't know" equal to 0
	
	foreach var of varlist q507* {
	replace `var' = 0 if `var' == . & mis_el_ch_survey !=1
	}
	
	
	** Making dummy for 508:
	// a = Yes
	foreach var of varlist q508*{
	gen q`var'_a = (`var' == 1) if `var' != .
	}
	

	** Make dummies for question 509

	label def 	q509_watntobecome 1 "Yes" 0 "No"	
	forvalues i = 1/27 {
	gen q509_watntobecome`i' = `i' if regexm(q509_watntobecome, "`i'")
	replace q509_watntobecome`i' = 1 if q509_watntobecome`i' !=.
	replace q509_watntobecome`i' = 0 if q509_watntobecome`i' ==.
	replace q509_watntobecome`i' = . if q509_watntobecome == ""
	lab values q509_watntobecome`i' q509_watntobecome
}

	order q509_watntobecome1-q509_watntobecome27, after(q509_watntobecome)
	
	** For 509, group into familial adult / peer / professional
	// teacher, doctor, police, working professional
	// 4, 10, 12, 21
	
	gen q509_prof_dum = q509_watntobecome4 == 1 | q509_watntobecome10 == 1 | q509_watntobecome12 == 1 | q509_watntobecome21== 1 if q509_watntobecome != ""
	// parent, other adult relative
	// 1, 2
	gen q509_adult_dum = q509_watntobecome1 == 1 | q509_watntobecome2 == 1 if q509_watntobecome != ""
	// sibling, same sex friend, opposite sex friend, one of my siblings
	// 3, 5, 6, 22
	gen q509_peer_dum = q509_watntobecome3 == 1 | q509_watntobecome5 == 1 | q509_watntobecome6 == 1 | q509_watntobecome22 == 1 if q509_watntobecome != ""
	
	** For 510, recode so that 1 = wait for 60 rupees, 0 = get 30 now
	replace q510a_60rs_30rs = (q510a_60rs_30rs == 1) if q510a_60rs_30rs != .
	
	** 511a
	
	gen q511a_a = (q511a_goal == 1) if q511a_goal != .
	gen q511a_b = (q511a_goal != 6) if q511a_goal != .

	// a = Education related goal
	// b = Has a goal at all
	
	** 512c
	
	gen q512c_a = (q512c_what == 1) if q512c_what != . 
	gen q512c_b = (q512c_what != 7) if q512c_what != .

	// a = Education related goal
	// b = Has a goal at all
	
	** 512b - steps
	
	gen q512b_a = 0 if q511a_goalnxtwk_achv != . 
	replace q512b_a = 1 if (q512b_stepsnextwk_achiev1 != 99 & q512b_stepsnextwk_achiev1 != . ) 
	// has at least one step

	
	** 512d - steps
	
	gen q512d_a = 0 if q512c_whatisgoal_nxtyr != . 
	replace q512d_a = 1 if (q512d_steps_nxtyr3 != "") 
	// has at least one step
	
	** 512e: 
	gen q512e_a = (q512e_exctd != 5) if q512e_exctd != . 
	gen q512e_dum = inlist(q512e_exctd, 3,4) if q512e_exctd != . 

	// a = has thought about goals
	// b = excited (yes = somewhat / very true)
	
	gen q512f_dum = inlist(q512f_sticktoplan, 3, 4) if q512f_sticktoplan != . // making lack of response not excited
	replace q512f_dum = . if q703 == . & q704==. & q705 == .
	// 512f, make 3 or 4 = 1, making 1 or 2 = 0
	
	
	// No observations (or strings)
	drop q512b_stepsnextwk_achiev* q512d_steps_nxtyr1 q512d_steps_nxtyr2 q512d_steps_nxtyr3 q512g_knwtodo_1yr 
	
	** 513f: replace "don't knows" with "Nos"
	
	replace q513f = 0 if q513f == . & q703 != .

	
	** 514: different occupations
	
	gen q514b_professional = inlist(q514b_kindjob, 1, 3, 4, 8, 12, 13, 16, 19, 23, 24, 27) if q514a != . 
	
	** Grouping amount of schooling
	gen q514c_further = (q514c_leadtedu != 1) if q514c_leadtedu !=.  // now 1 is wants further education (positive)
	// no further schooling
	gen q514c_pastprimary = (q514c_leadtedu >=4) if q514c_leadtedu !=. 
	// past primary
	gen q514c_tertiary = inlist(q514c_leadtedu, 6, 7, 8) if q514c_leadtedu !=. 
	// tertiary education
	
	** Same for 514d
	gen q514d_further = (q514d_highedu_finish != 1) if q514d_highedu_finish !=. 
	// no further schooling
	gen q514d_pastprimary = (q514d_highedu_finish >= 4) if q514d_highedu_finish !=. 
	// coded values of schooling, dropping "no futher school" "vocational" and "teacher"
	gen q514d_tertiary = inlist(q514d_highedu_finish, 6, 7, 8) if q514d_highedu_finish !=. 
	// "Teacher" or "vocational"

	
	** 514f, study in different school vs. anything other than school
	gen q514f_study = (q514f_whtdo_after==1) if q514f_whtdo_after != .
	
	** i: girls schooling issues. Dropping "other" / very few responses
	
	drop q514i_issues_girlsschlng98 q514i_issues_girlsschlng0 q514i_issues_girlsschlng8 q514i_issues_girlsschlng18 q514i_issues_girlsschlng28 q514i_issues_girlsschlng29 q514i_issues_girlsschlng30 q514i_issues_girlsschlng31 q514i_issues_girlsschlng32 q514i_issues_girlsschlng33 q514i_issues_girlsschlng34 q514i_issues_girlsschlng35 q514i_issues_girlsschlng99


	** Marking as missing to line up with other missing variables (7 kids who didn't finish the survey)
	foreach var of varlist q514i* q509_prof_dum q509_peer_dum q509_adult_dum {
	replace `var' = . if q703 == . & q704==. & q705 == .
	}
	
	** 515 ** : just recode to 0/1
	
	global q515_positive q515d q515e
	global q515_negative q515a q515b q515c q515f
	
	foreach var of varlist $q515_positive {
	gen q`var' = (`var' == 1) if `var' != . 
	}
	
	foreach var of varlist $q515_negative {
	gen q`var'_flip = (`var' == 0) if `var' != .
	}
	
	** 516: flip b
	
	gen q516b_payattn_flip = (q516b_dullcls_payattn == 0) if q516b_dullcls_payattn != . 
	
	** Enumerator assessment individual questions: keep 702-705
	
	gen q702_payattn_dum = (q702_patattn_instrutns == 3) if q702_patattn_instrutns != . 
	gen q732_carfl_dum = (q703_carfl_accur == 3) if q703_carfl_accur != . 
	gen q704_alert_dum = (q704_alert_interactve == 3) if q704_alert_interactve != . 
	gen q705_shy_conf_dum = (q705_shy_confident == 3) if q705_shy_confident != . 
	
	** Child questions
	global questions q501a_dum q501b q501c q501d q501e q501f_brrwmny q502a_talk_dum q502b_share_dum q502c_help_dum q503a_numbers_places* q503b_a* q503b_b* q503c_a* q503c_b* q504_areu_currmarrd_flip qq504* $q505_incl q507* qq508* q509_prof_dum q509_adult_dum q509_peer_dum q510a q511a_a q511a_b q512c_a q512c_b q512b_a q512d_a q512e_a q512e_dum q512f_dum q513* q514a q514b_professional q514c_further q514c_pastprimary q514c_tertiary q514d_further q514d_pastprimary q514d_tertiary q514f_study q514i* qq515* q516a_saddo_smthngbttr q516b_payattn_flip q702_payattn_dum q732_carfl_dum q704_alert_dum q705_shy_conf_dum

	**************** Household question measures *****************************
	
	// Making a dummy version (use this version!)
	
	global a416_positive a416a a416d a416g a416i a416k_good_frnd_ a416m a416p a416q a416r a416u
	global a416_negative a416b a416c a416e a416f a416h a416j a416l a416n a416o a416s a416t 
	
	** Putting f: "Would rather be alone than with other youth" as negative
	** Putting s: "Gets aong better with adults than with other youth" as negative (but unclear)
	
	//  1 = "certainly true", since almost all say 2/3
	foreach var of varlist $a416_positive {
	gen a`var' = (`var' == 3) if `var' != .
	}
	
	// for negative, 1 is "not true" or "somewhat true"
	foreach var of varlist $a416_negative {
	gen a`var'_flip = (`var' == 1) if `var' != .
	}
	
	
	// 417 making dummy for fairly often or almost always
	foreach var of varlist a417* {
	gen a`var' = inlist(`var', 3, 4 ,5) if `var' != .
	}
	
	** 418 is equivalent to child survey 503c
	drop a418k* //"Other" responses
	
	foreach var of varlist a418* {
	gen a`var'a= (`var' == 1) if `var' != .
	gen a`var'b= (`var' == 1 | `var' == 3) if `var' != .
	//gen a`var'c= (`var' != 4) if `var' != .
	}
	

	** 420 making dummy where 1 = a lot of say
	
	foreach var of varlist a420* {
	gen a`var' = (`var' == 3) if `var' != .
	}
	
	** 424, flip the negative statements: b, c, d, e
	foreach var of varlist a424b_husband_ a424c_high_educ_ a424d_dowry_ a424e_money_scarce_ a424h_studying_ {
	gen flip_`var' = `var' + 1
	replace flip_`var' = 0 if flip_`var' == 2
	}
	
		
	** 425/26, grouping like child was grouped
	gen a425_further = (a425_low_lev_schl_ != 1) if a425_low_lev_schl_ !=. 
	// no further schooling
	gen a425_pastprimary = (a425_low_lev_schl_ >=4) if a425_low_lev_schl_ !=. 
	// past primary
	gen a425_tertiary = inlist(a425_low_lev_schl_, 6, 7) if a425_low_lev_schl_ !=. 
	// tertiary education
	
	gen a426_further = (a426_highest_ != 1) if a426_highest_ !=.  // Now 1 is good: further education
	// no further schooling
	gen a426_pastprimary = (a426_highest_ >=4) if a426_highest_ !=. 
	// past primary
	gen a426_tertiary = inlist(a426_highest_, 6, 7) if a426_highest_ !=. 
	// tertiary education
	
	
	
	** 427 flip: 1 = do not think she could actually end schooling before this point
	gen flip_a427_point_ = a427_point_ + 1
	replace flip_a427_point_ = 0 if flip_a427_point_ == 2	

	** Constraints to girls' education dummy
	// dummy where 1 is good: they identified constraints
	
	gen a428_constraints = 0 if a428_obstacle_girl_ == "0" & a428_obstacle_girl_ != ""
	replace a428_constraints = 1 if a428_obstacle_girl_ != "0" & a428_obstacle_girl_ != ""
	
	** Create dummies out of strings
	forvalues x = 0/98 {
	gen a428_obstacle_girl_`x'_ = regexm(a428_obstacle_girl_, "`x'")
	replace a428_obstacle_girl_`x'_ = . if a428_obstacle_girl_ == ""
}
	drop a428_obstacle_girl_24_-a428_obstacle_girl_97_ 
	order a428_obstacle_girl_0_-a428_obstacle_girl_98_, after(a428_obstacle_girl_)

	lab define a428 1 "Yes" 0 "No"
	lab values a428_obstacle_girl_0_-a428_obstacle_girl_98_ a428

	** 428: dropping the non reshaped version and the other
	drop a428_obstacle_girl_ a428_obstacle_girl_0_ a428_obstacle_girl_98_ a428_obstacle_girl_17_-a428_obstacle_girl_23_
	// dropping the _0_ variable because it includes people who said 'no constraints' and then listed constraints
	
	drop a429_gto_school_oth_ a429_gto_school_ // drop non-reshaped
	drop a430l*

	** household vars
	global household_vars aa416* aa417* aa418* a419* aa420* flip_a424* a424a_wrk_out_hme_ a424f_same_amt_chore_ a424g_freedom_boy_ a424i_leaders_ a425_further a425_pastprimary a425_tertiary a426_further a426_pastprimary a426_tertiary flip_a427_point_ a428* a431_girl_marriage_age_ a433_ideal_age_marriage_ a434_old_age_married_ a436_advant_girl_

	
	** Make sure they're missing when they should be
	foreach var of varlist $questions {
	replace `var' = . if mis_el_ch_survey == 1
	}
	
	
	foreach var of varlist $household_vars {
	replace `var' = . if mis_el_hh_survey == 1
	}
	** No real changes made: all are missing when they should be
	
	
	************************* Skills indexes *******************************
	
	// self confidence
	foreach var of varlist q507a_feelimp q507b_gdatmath q507c_gdatredng q507d_comfrt_tchraskqtn qq508b_hopefuture_a qq508e_slvmostprblms_a qq515e_girlboy_smefreedm aa416o_nervous__flip aa417d_learn_new_thing_ {
	egen `var'_sd=sd(`var') if treat==0 & `var'!=.
	levelsof `var'_sd, local(x)
	replace `var'_sd=`x'
	egen `var'_mean=mean(`var') if treat==0 & `var'!=.
	levelsof `var'_mean, local(x)
	replace `var'_mean=`x'
	gen norm_`var'=(`var'-`var'_mean)/`var'_sd if `var'!=.
	}

	egen x=rowtotal(norm_*), missing 
	egen y= rownonmiss(norm_*) 
	gen index_selfconf=x/y
	drop q507a_feelimp_sd-y
	
	// emotion	
	
	foreach var of varlist q501d_prob_smeonetalk q516a_saddo_smthngbttr q516b_payattn_flip aa416h_worries__flip aa416l_unhappy__flip {
	egen `var'_sd=sd(`var') if treat==0 & `var'!=.
	levelsof `var'_sd, local(x)
	replace `var'_sd=`x'
	egen `var'_mean=mean(`var') if treat==0 & `var'!=.
	levelsof `var'_mean, local(x)
	replace `var'_mean=`x'
	gen norm_`var'=(`var'-`var'_mean)/`var'_sd if `var'!=.
	}

	egen x=rowtotal(norm_*), missing 
	egen y= rownonmiss(norm_*) 
	gen index_emotion=x/y
	drop q501d_prob_smeonetalk_sd-y
	
	
		
	// empathy
	
	foreach var of varlist q502c_help_dum aa416d_book_ aa416i_helpful_ aa416p_child_ aa416q_help_oth_ {
	egen `var'_sd=sd(`var') if treat==0 & `var'!=.
	levelsof `var'_sd, local(x)
	replace `var'_sd=`x'
	egen `var'_mean=mean(`var') if treat==0 & `var'!=.
	levelsof `var'_mean, local(x)
	replace `var'_mean=`x'
	gen norm_`var'=(`var'-`var'_mean)/`var'_sd if `var'!=.
	}

	egen x=rowtotal(norm_*), missing 
	egen y= rownonmiss(norm_*) 
	gen index_empathy=x/y
	drop q502c_help_dum_sd-y
	
	
	// self=control
	
	foreach var of varlist q510a_60rs_30rs aa416r_think_before_ aa416u_span_ aa416b_restless__flip aa416n_distracted__flip aa417c_facing_diffulties_ aa416p_child_ aa416q_help_oth_ q516b_payattn_flip {
	egen `var'_sd=sd(`var') if treat==0 & `var'!=.
	levelsof `var'_sd, local(x)
	replace `var'_sd=`x'
	egen `var'_mean=mean(`var') if treat==0 & `var'!=.
	levelsof `var'_mean, local(x)
	replace `var'_mean=`x'
	gen norm_`var'=(`var'-`var'_mean)/`var'_sd if `var'!=.
	}

	egen x=rowtotal(norm_*), missing 
	egen y= rownonmiss(norm_*) 
	gen index_selfcontrol=x/y
	drop q510a_60rs_30rs_sd-y

	
	// decision makig
	
	foreach var of varlist qq504a_social_outhome_a qq504a_social_outhome_b qq504b_gotoschl_a qq504b_gotoschl_b qq504c_contschl_pst8thgd_a qq504c_contschl_pst8thgd_b qq504d_whou_marry_a qq504d_whou_marry_b qq504e_whenu_getmarrd_a qq504e_whenu_getmarrd_b qq504f_mvinlaws_aftmrrg_a qq504f_mvinlaws_aftmrrg_b qq504g_wrkaftstudies_a qq504g_wrkaftstudies_b qq504h_typeofwrk_a qq504h_typeofwrk_b qq504i_spndfree_time_a qq504i_spndfree_time_b qq504j_chorsdo_athme_a qq504j_chorsdo_athme_b qq504k_spndtime_wthfrnds_a qq504k_spndtime_wthfrnds_b qq508a_mkplans_future_a  q511a_b q512c_b q512b_a q512d_a q512e_a q512f_dum q514a_jobpay_futre q514b_professional aa417b_goals_ qq508b_hopefuture_a aa416r_think_before_ {
	egen `var'_sd=sd(`var') if treat==0 & `var'!=.
	levelsof `var'_sd, local(x)
	replace `var'_sd=`x'
	egen `var'_mean=mean(`var') if treat==0 & `var'!=.
	levelsof `var'_mean, local(x)
	replace `var'_mean=`x'
	gen norm_`var'=(`var'-`var'_mean)/`var'_sd if `var'!=.
	}

	egen x=rowtotal(norm_*), missing 
	egen y= rownonmiss(norm_*) 
	gen index_decision=x/y
	drop qq504a_social_outhome_a_sd-y
	
	// perseverance
	
	rename qq508f_spndext_timegetright_a qq508f_spnd_time_a
	
	
	foreach var of varlist qq508c_finddiffway_a qq508f_spnd_time_a qq508g_succbcz_wrkhard_a aa417a_point_view_ qq508e_slvmostprblms_a q512f_dum {
	egen `var'_sd=sd(`var') if treat==0 & `var'!=.
	levelsof `var'_sd, local(x)
	replace `var'_sd=`x'
	egen `var'_mean=mean(`var') if treat==0 & `var'!=.
	levelsof `var'_mean, local(x)
	replace `var'_mean=`x'
	gen norm_`var'=(`var'-`var'_mean)/`var'_sd if `var'!=.
	}

	egen x=rowtotal(norm_*), missing 
	egen y= rownonmiss(norm_*) 
	gen index_perseverance=x/y
	drop qq508c_finddiffway_a_sd-y
	
	// communication
	
	foreach var of varlist q505d_talkparnts_schlng q505e_talkparnts_whomarry q505f_talkpartns_whnimarry q505g_typwrk_wntdo_futre q505h_talkprnts_prbwthfrnds aa417e_opinion_ a419a_worries_ a419b_gng_well_ a419c_eduction_ a419d_when_married_ a419e_who_marry_ a419f_wrk_future_ a419g_pbrlm_school_ q507d_comfrt_tchraskqtn {
	egen `var'_sd=sd(`var') if treat==0 & `var'!=.
	levelsof `var'_sd, local(x)
	replace `var'_sd=`x'
	egen `var'_mean=mean(`var') if treat==0 & `var'!=.
	levelsof `var'_mean, local(x)
	replace `var'_mean=`x'
	gen norm_`var'=(`var'-`var'_mean)/`var'_sd if `var'!=.
	}

	egen x=rowtotal(norm_*), missing 
	egen y= rownonmiss(norm_*) 
	gen index_communication=x/y
	drop q505d_talkparnts_schlng_sd-y
	
	// relationship building
	
	foreach var of varlist q501a_dum q501b_metfrnd_outside q501c_plcmeet_femfrnds q501e_staying_ngt q501f_brrwmny_emg q502a_talk_dum q502b_share_dum q503a_numbers_places_3 aa416k_good_frnd_ aa416f_alone__flip q501d_prob_smeonetalk q502c_help_dum {
	egen `var'_sd=sd(`var') if treat==0 & `var'!=.
	levelsof `var'_sd, local(x)
	replace `var'_sd=`x'
	egen `var'_mean=mean(`var') if treat==0 & `var'!=.
	levelsof `var'_mean, local(x)
	replace `var'_mean=`x'
	gen norm_`var'=(`var'-`var'_mean)/`var'_sd if `var'!=.
	}

	egen x=rowtotal(norm_*), missing 
	egen y= rownonmiss(norm_*) 
	gen index_relationship=x/y
	drop q501a_dum_sd-y
	
	// creative problem solving
	
	foreach var of varlist qq508c_finddiffway_a qq508f_spnd_time_a aa417a_point_view_ aa417c_facing_diffulties_ {
	egen `var'_sd=sd(`var') if treat==0 & `var'!=.
	levelsof `var'_sd, local(x)
	replace `var'_sd=`x'
	egen `var'_mean=mean(`var') if treat==0 & `var'!=.
	levelsof `var'_mean, local(x)
	replace `var'_mean=`x'
	gen norm_`var'=(`var'-`var'_mean)/`var'_sd if `var'!=.
	}

	egen x=rowtotal(norm_*), missing 
	egen y= rownonmiss(norm_*) 
	gen index_creativeprobsolv=x/y
	drop qq508c_finddiffway_a_sd-y

	** Save
	save "$merged_data/nine_skills.dta",replace
	
	
