** Makes the output used in Tables 13 and 14

	use "$merged_data/nine_skills.dta",clear
	
	** Child survey questions
	global questions q501a_dum q501b q501c q501d q501e q501f_brrwmny q502a_talk_dum q502b_share_dum q502c_help_dum q503a_numbers_places* q503b_a* q503b_b* q503c_a* q503c_b* q504_areu_currmarrd_flip qq504* $q505_incl q507* qq508* q509_prof_dum q509_adult_dum q509_peer_dum q510a q511a_a q511a_b q512c_a q512c_b q512b_a q512d_a q512e_a q512e_dum q512f_dum q513* q514a q514b_professional q514c_further q514c_pastprimary q514c_tertiary q514d_further q514d_pastprimary q514d_tertiary q514f_study q514i* qq515* q516a_saddo_smthngbttr q516b_payattn_flip q702_payattn_dum q732_carfl_dum q704_alert_dum q705_shy_conf_dum
	
	** Household survey questions
	global household_vars aa416* aa417* aa418* a419* aa420* flip_a424* a424a_wrk_out_hme_ a424f_same_amt_chore_ a424g_freedom_boy_ a424i_leaders_ a425_further a425_pastprimary a425_tertiary a426_further a426_pastprimary a426_tertiary flip_a427_point_ a428* a431_girl_marriage_age_ a433_ideal_age_marriage_ a434_old_age_married_ a436_advant_girl_
	
	** Indices
	global indices index_*
	
	** Controls for regressions
	global nocontrols treat stratafixed*, cl(dise) 
	

	local line=1
	local sel=`line'+1
	g Xvar=" "
	g Xorder=.
	g Xcon=.
	g Xb=.
	g Xperc=.
	g Xp=.
	
	
	** Run regressions, compute q-values, store percentage changes
	
	foreach var of varlist $questions $household_vars $indices{
		reg `var' $nocontrols
	
		replace Xvar="`var'" in `line'
		replace Xorder=`line' in `line'
		replace Xb=_b[treat] in `line'
		replace Xb=_se[treat] in `sel'
		replace Xp=(2 * ttail(e(df_r), abs(_b[treat]/_se[treat]))) in `line'

	reg `var' treat, cl(dise)
	
		replace Xcon=_b[_cons] in `line'
		replace Xcon=_se[_cons] in `sel'
		replace Xperc=Xb/Xcon in `line'
		local line=`line'+2
		local sel=`line'+1
	}
	
	keep Xvar-Xp
	drop if Xb==.
	
	*** CALCULATING P-VALUES & OUTPUT ***

	#delimit ;
	
	preserve;
	
	
	*compute significance based on fixed fdr;
	keep Xorder Xp;
	drop if Xp==.;
	local fdr=0.25;
	sort Xp;
	g order=_n;
	count;
	local num=r(N);
	g cBH=(order/`num')*`fdr';
	g value=" ";
	replace value="*" if Xp<cBH & Xp<0.05;
	
	*compute q-value;

	local qval = 1;

	* Generate the variable that will contain the BH (1995) q-values;

	gen bh95_qval = `qval' ;

	/* Set up a loop that begins by checking which hypotheses are rejected at q = 1.000, then checks which hypotheses are rejected at q = 0.999, then checks which hypotheses are rejected at q = 0.998, etc.  
	The loop ends by checking which hypotheses are rejected at q = 0.001.*/;
qui {;
	while `qval' > 0 {;
		* Generate value qr/M;
		quietly gen fdr_temp = `qval'*order/`num';
		* Generate binary variable checking condition p(r) <= qr/M;
		quietly gen reject_temp = (fdr_temp>=Xp) if fdr_temp~=.;
		* Generate variable containing p-value ranks for all p-values that meet above condition;
		quietly gen reject_rank = reject_temp*order;
		* Record the rank of the largest p-value that meets above condition;
		quietly egen total_rejected = max(reject_rank);
		* A p-value has been rejected at level q if its rank is less than or equal to the rank of the max p-value that meets the above condition;
		replace bh95_qval = `qval' if order <= total_rejected & order~=.;
		* Reduce q by 0.001 and repeat loop;
		quietly drop fdr_temp reject_temp reject_rank total_rejected;
		local qval = `qval' - .001;
	};
		
	};
	
	keep Xorder value bh95_qval;
	sort Xorder;
	tempfile FDR;
	save `FDR';
	restore;
	
	g mark=1 if Xorder~=.;
	replace mark=2 if Xorder==.;
	
	g XN=Xorder[_n-1];
	replace Xorder=XN if Xorder==.;
	drop XN;
	
	merge m:1 Xorder using `FDR';
	
	*These regressions have errors;
	list Xvar if _merge==1;
	
	*Get ready to export to excel;
	
	*first clean up the regression output;
	tostring Xcon Xb Xp bh95_qval, replace force format(%9.3f);
	replace Xperc=Xperc*100; tostring Xperc, replace force format(%9.1f);

	sort Xorder mark;
	
	*Parenthesis around standard errors;
	g o="("; g c=")"; replace Xcon=o+Xcon+c if Xvar==" "; replace Xb=o+Xb+c if Xvar==" "; drop o c;

	foreach var of varlist value bh95_qval Xp Xperc {;
	replace `var'=" " if mark==2;
	};
	
	label var Xvar "Variable"; 
	label var Xcon "Control Mean / (SE)";
	label var Xb "Treatment Mean / (SE)";
	label var value "P<0.05 & FDR<0.25";
	label var Xp "P-value";
	label var bh95_qval "Q-Statistic";
	label var Xperc "Percentage Change";
	
	keep Xvar Xcon Xb value  Xp bh95_qval Xperc;
	order Xvar Xcon Xb value Xp bh95_qval Xperc;
	
	export excel "$tables/Tables13_14.xls", replace  firstrow(varlabels) ;


