** Replication regressions

	** Load endline data
	use "$merged_data/endline_indices.dta", clear
	
	** Merge in baseline data for controls
	merge 1:1 child_id using "$merged_data/bl_indices.dta"
	
	tab _merge if mis_el == 1
	** Correclty identified the girls not in the endline survey
	
	drop if _merge == 2 
	drop _merge

** Creating indices for heterogeneous effects

	gen treat_maternaleduc_int=treat*mompostprim 
	label var treat_maternaleduc_int "Treatment X Maternal education"
	
	gen treat_quality_int=treat*stratafixed2
	label var treat_quality_int "Treatment X School quality"
	replace treat_quality_int = . if stratafixed3==1 // don't want new schools included in this
	
	gen treat_age_int=treat*bl_q203_age
	label var treat_age_int "Treatment X Age"
	
	gen treat_economicshock_int=treat*bl_economicshock
	label var treat_economicshock_int "Treatment X Economic shock"
	
	gen treat_deathillshock_int=treat*bl_deathillshock
	label var treat_deathillshock_int "Treatment X Death / illness shock"
	
	gen treat_crimedisputeshock_int=treat*bl_crimedisputeshock
	label var treat_crimedisputeshock_int "Treatment X Crime shock"
	
	** Lists of controls
	
	** Panel A
	global nocontrols treat stratafixed*, cl(dise) 
	** Panel B, whcih also adds controls for baseline level
	global basiccontrols treat stratafixed* employ1-employ6 mis_employ1-mis_employ6 age2-age11 mis_age2- mis_age11, cl(dise)
	
	** Panel B when there is no baseline (ASER for test scores, additional for other objective measures)
	global asercontrols bl_index_dropout mis_bl_index_dropout bl_index_grade mis_bl_index_grade bl_school_attend mis_bl_school_attend bl_time_homework bl_time_school mis_bl_time_homework mis_bl_time_school
	global additionalcontrols bl_index_socioemotional mis_bl_index_socioemotional bl_index_movement1 bl_index_empowerment mis_bl_index_empowerment bl_index_selfesteem mis_bl_index_selfesteem bl_index_planning mis_bl_index_planning bl_index_marr_expect mis_bl_index_marr_expect bl_index_employ mis_bl_index_employ bl_index_gender mis_bl_index_gender bl_index_cantrill mis_bl_index_cantrill bl_index_enumerator mis_bl_index_enumerator 	
	
	** Panel C adds imbalance controls
	** imabalance controls: OBC, child works, hours active outside of house
	global imbalancecontrols stratafixed* bl_obc mis_bl_obc bl_work_child mis_bl_work_child bl_hours_outside mis_bl_hours_outside

	** Controls for heterogeneous effects
	global het1controls treat treat_quality_int stratafixed1 stratafixed2 employ1-employ6 mis_employ1-mis_employ6 age2-age11 mis_age2- mis_age11, cl(dise) 
	global het2controls treat treat_age_int bl_q203_age stratafixed* employ1-employ6 mis_employ1-mis_employ6 age2-age11 mis_age2- mis_age11, cl(dise) 
	global het3controls treat treat_maternaleduc_int mompostprim stratafixed* employ1-employ6 mis_employ1-mis_employ6 age2-age11 mis_age2- mis_age11, cl(dise) 
	global het4controls treat treat_economicshock_int bl_economicshock stratafixed* employ1-employ6 mis_employ1-mis_employ6 age2-age11 mis_age2- mis_age11, cl(dise) 
	global het5controls treat treat_crimedisputeshock_int bl_crimedisputeshock stratafixed* employ1-employ6 mis_employ1-mis_employ6 age2-age11 mis_age2- mis_age11, cl(dise) 
	global het6controls treat treat_deathillshock_int bl_deathillshock stratafixed* employ1-employ6 mis_employ1-mis_employ6 age2-age11 mis_age2- mis_age11, cl(dise) 
	
	** List of table 6 variables
	global table6 el_index_delay el_index_attempts el_index_time el_index_scavenger el_index_marriage-el_index_enumerator el_index_p_strengths-el_index_rosenberg
	global table6_bl bl_index_delay bl_index_attempts bl_index_time bl_index_scavenger bl_index_marriage-bl_index_enumerator bl_index_p_strengths-bl_index_rosenberg
	
	
	** Make list of all variables to get means
	global all_vars el_index_dropout el_index_grade el_school_attend el_school_dummy el_index_delay el_index_attempts el_index_time el_index_scavenger el_index_marriage el_index_socioemotional el_index_movement1 el_index_empowerment el_index_selfesteem el_index_planning el_index_marr_expect el_index_employ el_index_gender el_index_cantrill el_index_enumerator el_index_p_strengths el_index_p_efficacy el_index_p_movement1 el_index_p_communication el_index_p_gender el_index_p_schooling el_index_p_marriage  el_index_locus_control el_index_stress el_index_rosenberg el_work_child el_work_pay el_work_nonfamily el_child_labor el_hazardous_labor el_otherworst_labor el_hours_worked el_hours_unpd_hhser el_hours_active el_hours_outside el_time_homework el_time_school el_mathproficiency el_hindiproficiency el_englishproficiency
	
	** Get endline means for control group for tables 5-8 (bottom row of tables)
	preserve
	
	keep if treat ==0
	tabstat $all_vars ,statistics(mean) columns(statistics) varwidth(24) format(%8.3f) save

	mat T = r(StatTotal)' 

	putexcel set "$tables/summary/El_control_means.xlsx",replace 
	putexcel A1 = matrix(T), names
	
	
	restore
	**** Tables 5 & 9
	**** School attendance	
		
	** Panel A
		reg el_index_dropout $nocontrols
		eststo outcome5a_1
			
		reg el_index_grade $nocontrols
		eststo outcome5a_2
		
		reg el_school_attend $nocontrols
		eststo outcome5a_3
		
		reg el_school_dummy $nocontrols
		eststo outcome5a_4
		
		esttab outcome5a_1 outcome5a_2 outcome5a_3 outcome5a_4  using "$tables/table5/table5_A.csv", ar2 se(%9.3f) b(%9.3f) noconstant varwidth(30) nogaps compress label keep(treat) replace star(* 0.10 ** 0.05 *** 0.01)
		
		
	** Panel B	
		reg el_index_dropout bl_index_dropout mis_bl_index_dropout $basiccontrols
		eststo outcome5b_1
			
		reg el_index_grade bl_index_grade mis_bl_index_grade $basiccontrols
		eststo outcome5b_2
		
		reg el_school_attend bl_school_attend mis_bl_school_attend $basiccontrols
		eststo outcome5b_3
		
		reg el_school_dummy bl_school_dummy mis_bl_school_dummy $basiccontrols
		eststo outcome5b_4
		
		esttab outcome5b_1 outcome5b_2 outcome5b_3 outcome5b_4  using "$tables/table5/table5_B.csv", ar2 se(%9.3f) b(%9.3f) noconstant varwidth(30) nogaps compress label keep(treat) replace star(* 0.10 ** 0.05 *** 0.01)
		
	** Panel C	
		reg el_index_dropout $imbalancecontrols bl_index_dropout mis_bl_index_dropout $basiccontrols
		eststo outcome5c_1
			 
		reg el_index_grade $imbalancecontrols bl_index_grade mis_bl_index_grade $basiccontrols
		eststo outcome5c_2
		
		reg el_school_attend $imbalancecontrols bl_school_attend mis_bl_school_attend $basiccontrols
		eststo outcome5c_3
		
		reg el_school_dummy $imbalancecontrols bl_school_dummy mis_bl_school_dummy $basiccontrols
		eststo outcome5c_4 
		
		esttab outcome5c_1 outcome5c_2 outcome5c_3 outcome5c_4  using "$tables/table5/table5_C.csv", ar2 se(%9.3f) b(%9.3f) noconstant varwidth(30) nogaps compress label keep(treat) replace star(* 0.10 ** 0.05 *** 0.01)
		
		eststo drop outcome5*
	** Table 9
	
	** Mother's education
		reg el_index_dropout $het1controls
		eststo outcome9a_1
			
		reg el_index_grade $het1controls
		eststo outcome9a_2
		
		reg el_school_attend $het1controls
		eststo outcome9a_3
		
		reg el_school_dummy $het1controls
		eststo outcome9a_4
	
	** School quality
	
		reg el_index_dropout $het2controls
		eststo outcome9b_1
			
		reg el_index_grade $het2controls
		eststo outcome9b_2
		
		reg el_school_attend $het2controls
		eststo outcome9b_3
		
		reg el_school_dummy $het2controls
		eststo outcome9b_4
	
	
	** age
	
		reg el_index_dropout $het3controls
		eststo outcome9c_1
			
		reg el_index_grade $het3controls
		eststo outcome9c_2
		
		reg el_school_attend $het3controls
		eststo outcome9c_3
		
		reg el_school_dummy $het3controls
		eststo outcome9c_4
		
	** economic shock
	
		reg el_index_dropout $het4controls
		eststo outcome9d_1
			
		reg el_index_grade $het4controls
		eststo outcome9d_2
		
		reg el_school_attend $het4controls
		eststo outcome9d_3
		
		reg el_school_dummy $het4controls
		eststo outcome9d_4
		
	** death/illness shock
	
		reg el_index_dropout $het5controls
		eststo outcome9e_1
			
		reg el_index_grade $het5controls
		eststo outcome9e_2
		
		reg el_school_attend $het5controls
		eststo outcome9e_3
		
		reg el_school_dummy $het5controls
		eststo outcome9e_4
				
	** crime/dispute shock
	
		reg el_index_dropout $het6controls
		eststo outcome9f_1
			
		reg el_index_grade $het6controls
		eststo outcome9f_2
		
		reg el_school_attend $het6controls
		eststo outcome9f_3
		
		reg el_school_dummy $het6controls
		eststo outcome9f_4
		
		esttab outcome9a_1 outcome9a_2 outcome9a_3 outcome9a_4 outcome9b_1 outcome9b_2 outcome9b_3 outcome9b_4 outcome9c_1 outcome9c_2 outcome9c_3 outcome9c_4  outcome9d_1 outcome9d_2 outcome9d_3 outcome9d_4 outcome9e_1 outcome9e_2 outcome9e_3 outcome9e_4  outcome9f_1 outcome9f_2 outcome9f_3 outcome9f_4 using "$tables/heterogeneous_effects/table9.csv", ar2 se(%9.3f) b(%9.3f) noconstant varwidth(30) nogaps compress label keep(treat*) replace star(* 0.10 ** 0.05 *** 0.01)
		
		eststo drop outcome9*
	****************************************
	** Tables 7 & 11
	** child labor
	
	** Panel A
		reg el_work_child $nocontrols
		eststo outcome7a_1
			
		reg el_work_pay $nocontrols
		eststo outcome7a_2
		
		reg el_work_nonfamily $nocontrols
		eststo outcome7a_3
		
		reg el_child_labor $nocontrols
		eststo outcome7a_4
		
		reg el_hazardous_labor $nocontrols
		eststo outcome7a_5
			
		reg el_otherworst_labor $nocontrols
		eststo outcome7a_6
			
		reg el_hours_worked $nocontrols
		eststo outcome7a_7
		
		reg el_hours_unpd_hhser $nocontrols
		eststo outcome7a_8
		
		reg el_hours_active $nocontrols
		eststo outcome7a_9
		
		reg el_hours_outside $nocontrols
		eststo outcome7a_10
		
		esttab outcome7a_1 outcome7a_2 outcome7a_3 outcome7a_4 outcome7a_5 outcome7a_6 outcome7a_7 outcome7a_8 outcome7a_9 outcome7a_10  using "$tables/table7/table7_A.csv", ar2 se(%9.3f) b(%9.3f) noconstant varwidth(30) nogaps compress label keep(treat) replace star(* 0.10 ** 0.05 *** 0.01)

	** Panel B	
		reg el_work_child bl_work_child mis_bl_work_child $basiccontrols
		eststo outcome7b_1
			
		reg el_work_pay bl_work_pay mis_bl_work_pay $basiccontrols
		eststo outcome7b_2
		
		reg el_work_nonfamily bl_work_nonfamily mis_bl_work_nonfamily $basiccontrols
		eststo outcome7b_3
		
		reg el_child_labor bl_child_labor mis_bl_child_labor $basiccontrols
		eststo outcome7b_4
		
		reg el_hazardous_labor bl_hazardous_labor mis_bl_hazardous_labor  $basiccontrols
		eststo outcome7b_5
			
		reg el_otherworst_labor bl_otherworst_labor mis_bl_otherworst_labor $basiccontrols
		eststo outcome7b_6
			
		reg el_hours_worked bl_hours_worked mis_bl_hours_worked $basiccontrols
		eststo outcome7b_7
		
		reg el_hours_unpd_hhser bl_hours_unpd_hhser mis_bl_hours_unpd_hhser $basiccontrols
		eststo outcome7b_8
		
		reg el_hours_active bl_hours_active mis_bl_hours_active $basiccontrols
		eststo outcome7b_9
		
		reg el_hours_outside bl_hours_outside mis_bl_hours_outside $basiccontrols
		eststo outcome7b_10
		
		esttab outcome7b_1 outcome7b_2 outcome7b_3 outcome7b_4 outcome7b_5 outcome7b_6 outcome7b_7 outcome7b_8 outcome7b_9 outcome7b_10 using "$tables/table7/table7_B.csv", ar2 se(%9.3f) b(%9.3f) noconstant varwidth(30) nogaps compress label keep(treat) replace star(* 0.10 ** 0.05 *** 0.01)
		
	** Panel C
	
		** Panel A
		reg el_work_child $imbalancecontrols bl_work_child mis_bl_work_child $basiccontrols
		eststo outcome7c_1
			
		reg el_work_pay $imbalancecontrols bl_work_pay mis_bl_work_pay $basiccontrols
		eststo outcome7c_2
		
		reg el_work_nonfamily $imbalancecontrols bl_work_nonfamily mis_bl_work_nonfamily $basiccontrols
		eststo outcome7c_3
		
		reg el_child_labor $imbalancecontrols bl_child_labor mis_bl_child_labor $basiccontrols
		eststo outcome7c_4
		
		reg el_hazardous_labor $imbalancecontrols bl_hazardous_labor mis_bl_hazardous_labor  $basiccontrols
		eststo outcome7c_5
			
		reg el_otherworst_labor $imbalancecontrols bl_otherworst_labor mis_bl_otherworst_labor $basiccontrols
		eststo outcome7c_6
			 
		reg el_hours_worked $imbalancecontrols bl_hours_worked mis_bl_hours_worked $basiccontrols
		eststo outcome7c_7
		
		reg el_hours_unpd_hhser $imbalancecontrols bl_hours_unpd_hhser mis_bl_hours_unpd_hhser $basiccontrols
		eststo outcome7c_8
		
		reg el_hours_active $imbalancecontrols bl_hours_active mis_bl_hours_active $basiccontrols
		eststo outcome7c_9
		
		reg el_hours_outside $imbalancecontrols bl_hours_outside mis_bl_hours_outside $basiccontrols
		eststo outcome7c_10
		
		esttab outcome7c_1 outcome7c_2 outcome7c_3 outcome7c_4 outcome7c_5 outcome7c_6 outcome7c_7 outcome7c_8 outcome7c_9 outcome7c_10  using "$tables/table7/table7_C.csv", ar2 se(%9.3f) b(%9.3f) noconstant varwidth(30) nogaps compress label keep(treat) replace star(* 0.10 ** 0.05 *** 0.01)

		eststo drop outcome7*
		
	** Table 12 
	
	** Mother's education
		
		reg el_work_child $het1controls
		eststo outcome11a_1
			
		reg el_work_pay $het1controls
		eststo outcome11a_2
		
		reg el_work_nonfamily $het1controls
		eststo outcome11a_3
		
		reg el_child_labor $het1controls
		eststo outcome11a_4
		
		reg el_hazardous_labor $het1controls
		eststo outcome11a_5
			
		reg el_otherworst_labor $het1controls
		eststo outcome11a_6
			
		reg el_hours_worked $het1controls
		eststo outcome11a_7
		
		reg el_hours_unpd_hhser $het1controls
		eststo outcome11a_8
		
		reg el_hours_active $het1controls
		eststo outcome11a_9
		
		reg el_hours_outside $het1controls
		eststo outcome11a_10
	
	** School quality
	
		reg el_work_child $het2controls
		eststo outcome11b_1
			
		reg el_work_pay $het2controls
		eststo outcome11b_2
		
		reg el_work_nonfamily $het2controls
		eststo outcome11b_3
		
		reg el_child_labor $het2controls
		eststo outcome11b_4
		
		reg el_hazardous_labor $het2controls
		eststo outcome11b_5
			
		reg el_otherworst_labor $het2controls
		eststo outcome11b_6
			
		reg el_hours_worked $het2controls
		eststo outcome11b_7
		
		reg el_hours_unpd_hhser $het2controls
		eststo outcome11b_8
		
		reg el_hours_active $het2controls
		eststo outcome11b_9
		
		reg el_hours_outside $het2controls
		eststo outcome11b_10
	
	
	** age
	
		reg el_work_child $het3controls
		eststo outcome11c_1
			
		reg el_work_pay $het3controls
		eststo outcome11c_2
		
		reg el_work_nonfamily $het3controls
		eststo outcome11c_3
		
		reg el_child_labor $het3controls
		eststo outcome11c_4
		
		reg el_hazardous_labor $het3controls
		eststo outcome11c_5
			
		reg el_otherworst_labor $het3controls
		eststo outcome11c_6
			
		reg el_hours_worked $het3controls
		eststo outcome11c_7
		
		reg el_hours_unpd_hhser $het3controls
		eststo outcome11c_8
		
		reg el_hours_active $het3controls
		eststo outcome11c_9
		
		reg el_hours_outside $het3controls
		eststo outcome11c_10
		
	** economic shock
	
		reg el_work_child $het4controls
		eststo outcome11d_1
			
		reg el_work_pay $het4controls
		eststo outcome11d_2
		
		reg el_work_nonfamily $het4controls
		eststo outcome11d_3
		
		reg el_child_labor $het4controls
		eststo outcome11d_4
		
		reg el_hazardous_labor $het4controls
		eststo outcome11d_5
			
		reg el_otherworst_labor $het4controls
		eststo outcome11d_6
			
		reg el_hours_worked $het4controls
		eststo outcome11d_7
		
		reg el_hours_unpd_hhser $het4controls
		eststo outcome11d_8
		
		reg el_hours_active $het4controls
		eststo outcome11d_9
		
		reg el_hours_outside $het4controls
		eststo outcome11d_10
		
	** death/illness shock
	
		reg el_work_child $het5controls
		eststo outcome11e_1
			
		reg el_work_pay $het5controls
		eststo outcome11e_2
		
		reg el_work_nonfamily $het5controls
		eststo outcome11e_3
		
		reg el_child_labor $het5controls
		eststo outcome11e_4
		
		reg el_hazardous_labor $het5controls
		eststo outcome11e_5
			
		reg el_otherworst_labor $het5controls
		eststo outcome11e_6
			
		reg el_hours_worked $het5controls
		eststo outcome11e_7
		
		reg el_hours_unpd_hhser $het5controls
		eststo outcome11e_8
		
		reg el_hours_active $het5controls
		eststo outcome11e_9
		
		reg el_hours_outside $het5controls
		eststo outcome11e_10
				
	** crime/dispute shock
	
		reg el_work_child $het6controls
		eststo outcome11f_1
			
		reg el_work_pay $het6controls
		eststo outcome11f_2
		
		reg el_work_nonfamily $het6controls
		eststo outcome11f_3
		
		reg el_child_labor $het6controls
		eststo outcome11f_4
		
		reg el_hazardous_labor $het6controls
		eststo outcome11f_5
			
		reg el_otherworst_labor $het6controls
		eststo outcome11f_6
			
		reg el_hours_worked $het6controls
		eststo outcome11f_7
		
		reg el_hours_unpd_hhser $het6controls
		eststo outcome11f_8
		
		reg el_hours_active $het6controls
		eststo outcome11f_9
		
		reg el_hours_outside $het6controls
		eststo outcome11f_10
		
		esttab outcome11a_1 outcome11a_2 outcome11a_3 outcome11a_4 outcome11a_5 outcome11a_6 outcome11a_7 outcome11a_8 outcome11a_9 outcome11a_10 outcome11b_1 outcome11b_2 outcome11b_3 outcome11b_4 outcome11b_5 outcome11b_6 outcome11b_7 outcome11b_8 outcome11b_9 outcome11b_10 outcome11c_1 outcome11c_2 outcome11c_3 outcome11c_4 outcome11c_5 outcome11c_6 outcome11c_7 outcome11c_8 outcome11c_9 outcome11c_10 outcome11d_1 outcome11d_2 outcome11d_3 outcome11d_4 outcome11d_5 outcome11d_6 outcome11d_7 outcome11d_8 outcome11d_9 outcome11d_10 outcome11e_1 outcome11e_2 outcome11e_3 outcome11e_4 outcome11e_5 outcome11e_6 outcome11e_7 outcome11e_8 outcome11e_9 outcome11e_10 outcome11f_1 outcome11f_2 outcome11f_3 outcome11f_4 outcome11f_5 outcome11f_6 outcome11f_7 outcome11f_8 outcome11f_9 outcome11f_10 using "$tables/heterogeneous_effects/table11.csv", ar2 se(%9.3f) b(%9.3f) noconstant varwidth(30) nogaps compress label keep(treat*) replace star(* 0.10 ** 0.05 *** 0.01)
		eststo drop outcome11*
		
	****************************************
	** Tables 8 & 12
	** school achievement
	
	** Panel A
		reg el_time_homework $nocontrols
		eststo outcome8a_1
			
		reg el_time_school $nocontrols
		eststo outcome8a_2
		
		reg el_mathproficiency $nocontrols
		eststo outcome8a_3
		
		reg el_hindiproficiency $nocontrols
		eststo outcome8a_4
		
		reg el_englishproficiency $nocontrols
		eststo outcome8a_5

		esttab outcome8a_1 outcome8a_2 outcome8a_3 outcome8a_4 outcome8a_5 using "$tables/table8/table8_A.csv", ar2 se(%9.3f) b(%9.3f) noconstant varwidth(30) nogaps compress label keep(treat) replace star(* 0.10 ** 0.05 *** 0.01)

	** Panel B	
		reg el_time_homework bl_time_homework mis_bl_time_homework $basiccontrols
		eststo outcome8b_1
			
		reg el_time_school bl_time_school mis_bl_time_school $basiccontrols
		eststo outcome8b_2
		
		reg el_mathproficiency $asercontrols $basiccontrols
		eststo outcome8b_3
		
		reg el_hindiproficiency $asercontrols $basiccontrols
		eststo outcome8b_4
		
		reg el_englishproficiency $asercontrols  $basiccontrols
		eststo outcome8b_5

		esttab outcome8b_1 outcome8b_2 outcome8b_3 outcome8b_4 outcome8b_5 using "$tables/table8/table8_B.csv", ar2 se(%9.3f) b(%9.3f) noconstant varwidth(30) nogaps compress label keep(treat) replace star(* 0.10 ** 0.05 *** 0.01)
		
	** Panel C
	
		reg el_time_homework $imbalancecontrols bl_time_homework mis_bl_time_homework $basiccontrols
		eststo outcome8c_1
			 
		reg el_time_school $imbalancecontrols bl_time_school mis_bl_time_school $basiccontrols
		eststo outcome8c_2
		
		reg el_mathproficiency $imbalancecontrols $asercontrols  $basiccontrols
		eststo outcome8c_3
		
		reg el_hindiproficiency $imbalancecontrols $asercontrols  $basiccontrols
		eststo outcome8c_4
		
		reg el_englishproficiency $imbalancecontrols $asercontrols  $basiccontrols
		eststo outcome8c_5
			
		esttab outcome8c_1 outcome8c_2 outcome8c_3 outcome8c_4 outcome8c_5 using "$tables/table8/table8_C.csv", ar2 se(%9.3f) b(%9.3f) noconstant varwidth(30) nogaps compress label keep(treat) replace star(* 0.10 ** 0.05 *** 0.01)

		eststo drop outcome8*
		
	** Table 12
	
	** Mother's education
		
		reg el_time_homework $het1controls
		eststo outcome12a_1
			
		reg el_time_school $het1controls
		eststo outcome12a_2
		
		reg el_mathproficiency $het1controls
		eststo outcome12a_3
		
		reg el_hindiproficiency $het1controls
		eststo outcome12a_4
		
		reg el_englishproficiency $het1controls
		eststo outcome12a_5
			
	
	** School quality
	
		reg el_time_homework $het2controls
		eststo outcome12b_1
			
		reg el_time_school $het2controls
		eststo outcome12b_2
		
		reg el_mathproficiency $het2controls
		eststo outcome12b_3
		
		reg el_hindiproficiency $het2controls
		eststo outcome12b_4
		
		reg el_englishproficiency $het2controls
		eststo outcome12b_5
		
	
	** age
	
		reg el_time_homework $het3controls
		eststo outcome12c_1
			
		reg el_time_school $het3controls
		eststo outcome12c_2
		
		reg el_mathproficiency $het3controls
		eststo outcome12c_3
		
		reg el_hindiproficiency $het3controls
		eststo outcome12c_4
		
		reg el_englishproficiency $het3controls
		eststo outcome12c_5
		
	** economic shock
	
		reg el_time_homework $het4controls
		eststo outcome12d_1
			
		reg el_time_school $het4controls
		eststo outcome12d_2
		
		reg el_mathproficiency $het4controls
		eststo outcome12d_3
		
		reg el_hindiproficiency $het4controls
		eststo outcome12d_4
		
		reg el_englishproficiency $het4controls
		eststo outcome12d_5

			
	** death/illness shock
	
		reg el_time_homework $het5controls
		eststo outcome12e_1
			
		reg el_time_school $het5controls
		eststo outcome12e_2
		
		reg el_mathproficiency $het5controls
		eststo outcome12e_3
		
		reg el_hindiproficiency $het5controls
		eststo outcome12e_4
		
		reg el_englishproficiency $het5controls
		eststo outcome12e_5
				
	** crime/dispute shock
	
		reg el_time_homework $het6controls
		eststo outcome12f_1
			
		reg el_time_school $het6controls
		eststo outcome12f_2
		
		reg el_mathproficiency $het6controls
		eststo outcome12f_3
		
		reg el_hindiproficiency $het6controls
		eststo outcome12f_4
		
		reg el_englishproficiency $het6controls
		eststo outcome12f_5
		
		esttab outcome12a_1 outcome12a_2 outcome12a_3 outcome12a_4 outcome12a_5 outcome12b_1 outcome12b_2 outcome12b_3 outcome12b_4 outcome12b_5 outcome12c_1 outcome12c_2 outcome12c_3 outcome12c_4 outcome12c_5 outcome12d_1 outcome12d_2 outcome12d_3 outcome12d_4 outcome12d_5 outcome12e_1 outcome12e_2 outcome12e_3 outcome12e_4 outcome12e_5 outcome12f_1 outcome12f_2 outcome12f_3 outcome12f_4 outcome12f_5 using "$tables/heterogeneous_effects/table12.csv", ar2 se(%9.3f) b(%9.3f) noconstant varwidth(30) nogaps compress label keep(treat*) replace star(* 0.10 ** 0.05 *** 0.01)	

		eststo drop outcome12*
		
		**** Table 6
		
		** Table 6-1
		** Panel A
		reg el_index_delay $nocontrols
		eststo outcome6_1a_1
			
		reg el_index_attempts $nocontrols
		eststo outcome6_1a_2
		
		reg el_index_time $nocontrols
		eststo outcome6_1a_3
		
		reg el_index_scavenger $nocontrols
		eststo outcome6_1a_4
		
		esttab outcome6_1a_1 outcome6_1a_2 outcome6_1a_3 outcome6_1a_4  using "$tables/table6/table6_1_A.csv", ar2 se(%9.3f) b(%9.3f) noconstant varwidth(30) nogaps compress label keep(treat) replace star(* 0.10 ** 0.05 *** 0.01)

		** Panel B
		reg el_index_delay bl_index_delay mis_bl_index_delay $basiccontrols
		eststo outcome6_1b_1
			
		reg el_index_attempts bl_index_attempts mis_bl_index_attempts $basiccontrols
		eststo outcome6_1b_2
		
		reg el_index_time bl_index_time mis_bl_index_time $basiccontrols
		eststo outcome6_1b_3
		
		reg el_index_scavenger  bl_index_scavenger mis_bl_index_scavenger $basiccontrols
		eststo outcome6_1b_4
		
		esttab outcome6_1b_1 outcome6_1b_2 outcome6_1b_3 outcome6_1b_4  using "$tables/table6/table6_1_B.csv", ar2 se(%9.3f) b(%9.3f) noconstant varwidth(30) nogaps compress label keep(treat) replace star(* 0.10 ** 0.05 *** 0.01)

		** Panel C
		reg el_index_delay $imbalancecontrols bl_index_delay mis_bl_index_delay $basiccontrols
		eststo outcome6_1c_1
			
		reg el_index_attempts $imbalancecontrols bl_index_attempts mis_bl_index_attempts $basiccontrols
		eststo outcome6_1c_2
		
		reg el_index_time $imbalancecontrols bl_index_time mis_bl_index_time $basiccontrols
		eststo outcome6_1c_3
		
		reg el_index_scavenger $imbalancecontrols bl_index_scavenger mis_bl_index_scavenger $basiccontrols
		eststo outcome6_1c_4
		
		esttab outcome6_1c_1 outcome6_1c_2 outcome6_1c_3 outcome6_1c_4  using "$tables/table6/table6_1_C.csv", ar2 se(%9.3f) b(%9.3f) noconstant varwidth(30) nogaps compress label keep(treat) replace star(* 0.10 ** 0.05 *** 0.01)

		eststo drop outcome6_1*
		
		** Table 6-2
		           	
		** Panel A
		reg el_index_marriage $nocontrols
		eststo outcome6_2a1
			
		reg el_index_socioemotional $nocontrols
		eststo outcome6_2a2
		
		reg el_index_movement1 $nocontrols
		eststo outcome6_2a3
		
		reg el_index_empowerment $nocontrols
		eststo outcome6_2a5
			
		reg el_index_selfesteem $nocontrols
		eststo outcome6_2a6
			
		reg el_index_planning $nocontrols
		eststo outcome6_2a7
			
		reg el_index_marr_expect $nocontrols
		eststo outcome6_2a8
		
		reg el_index_employ $nocontrols
		eststo outcome6_2a9
		
		reg el_index_gender $nocontrols
		eststo outcome6_2a10
		
		reg el_index_cantrill $nocontrols
		eststo outcome6_2a11
		
		reg el_index_enumerator $nocontrols
		eststo outcome6_2a12
		
		esttab outcome6_2a1 outcome6_2a2 outcome6_2a3 outcome6_2a5 outcome6_2a6 outcome6_2a7 outcome6_2a8 outcome6_2a9 outcome6_2a10 outcome6_2a11 outcome6_2a12 using "$tables/table6/table6_2_A.csv", ar2 se(%9.3f) b(%9.3f) noconstant varwidth(30) nogaps compress label keep(treat) replace star(* 0.10 ** 0.05 *** 0.01)

		** Panel B
		reg el_index_marriage bl_index_marriage mis_bl_index_marriage $basiccontrols
		eststo outcome6_2b1
			
		reg el_index_socioemotional bl_index_socioemotional mis_bl_index_socioemotional $basiccontrols
		eststo outcome6_2b2
		
		reg el_index_movement1 bl_index_movement1 mis_bl_index_movement1 $basiccontrols
		eststo outcome6_2b3
		
		reg el_index_empowerment bl_index_empowerment mis_bl_index_empowerment $basiccontrols
		eststo outcome6_2b5
			
		reg el_index_selfesteem bl_index_selfesteem mis_bl_index_selfesteem $basiccontrols
		eststo outcome6_2b6
			
		reg el_index_planning bl_index_planning mis_bl_index_planning $basiccontrols
		eststo outcome6_2b7
			
		reg el_index_marr_expect bl_index_marr_expect mis_bl_index_marr_expect $basiccontrols
		eststo outcome6_2b8
		
		reg el_index_employ bl_index_employ mis_bl_index_employ $basiccontrols
		eststo outcome6_2b9
		
		reg el_index_gender bl_index_gender mis_bl_index_gender $basiccontrols
		eststo outcome6_2b10
		
		reg el_index_cantrill bl_index_cantrill mis_bl_index_cantrill $basiccontrols
		eststo outcome6_2b11
		
		reg el_index_enumerator bl_index_enumerator mis_bl_index_enumerator $basiccontrols
		eststo outcome6_2b12
		
		esttab outcome6_2b1 outcome6_2b2 outcome6_2b3 outcome6_2b5 outcome6_2b6 outcome6_2b7 outcome6_2b8 outcome6_2b9 outcome6_2b10 outcome6_2b11 outcome6_2b12 using "$tables/table6/table6_2_B.csv", ar2 se(%9.3f) b(%9.3f) noconstant varwidth(30) nogaps compress label keep(treat) replace star(* 0.10 ** 0.05 *** 0.01)

		
		** Panel C
		reg el_index_marriage $imbalancecontrols bl_index_marriage mis_bl_index_marriage $basiccontrols
		eststo outcome6_2c1
			
		reg el_index_socioemotional $imbalancecontrols bl_index_socioemotional mis_bl_index_socioemotional $basiccontrols
		eststo outcome6_2c2
		
		reg el_index_movement1 $imbalancecontrols bl_index_movement1 mis_bl_index_movement1 $basiccontrols
		eststo outcome6_2c3

		reg el_index_empowerment $imbalancecontrols bl_index_empowerment mis_bl_index_empowerment $basiccontrols
		eststo outcome6_2c5
			
		reg el_index_selfesteem $imbalancecontrols bl_index_selfesteem mis_bl_index_selfesteem $basiccontrols
		eststo outcome6_2c6
			
		reg el_index_planning $imbalancecontrols bl_index_planning mis_bl_index_planning $basiccontrols
		eststo outcome6_2c7
			
		reg el_index_marr_expect $imbalancecontrols bl_index_marr_expect mis_bl_index_marr_expect $basiccontrols
		eststo outcome6_2c8
		
		reg el_index_employ $imbalancecontrols bl_index_gender mis_bl_index_gender $basiccontrols
		eststo outcome6_2c9
		
		reg el_index_gender $imbalancecontrols bl_index_gender mis_bl_index_gender $basiccontrols
		eststo outcome6_2c10
		
		reg el_index_cantrill $imbalancecontrols bl_index_cantrill mis_bl_index_cantrill $basiccontrols
		eststo outcome6_2c11
		
		reg el_index_enumerator $imbalancecontrols bl_index_enumerator mis_bl_index_enumerator $basiccontrols
		eststo outcome6_2c12
		
		esttab outcome6_2c1 outcome6_2c2 outcome6_2c3 outcome6_2c5 outcome6_2c6 outcome6_2c7 outcome6_2c8 outcome6_2c9 outcome6_2c10 outcome6_2c11 outcome6_2c12 using "$tables/table6/table6_2_C.csv", ar2 se(%9.3f) b(%9.3f) noconstant varwidth(30) nogaps compress label keep(treat) replace star(* 0.10 ** 0.05 *** 0.01)

		eststo drop outcome6_2*
		
		** Table 6-3
        
		** Panel A
		reg el_index_p_strengths $nocontrols
		eststo outcome6_3a1
			
		reg el_index_p_efficacy $nocontrols
		eststo outcome6_3a2
		
		reg el_index_p_movement1 $nocontrols
		eststo outcome6_3a3
		
		reg el_index_p_communication $nocontrols
		eststo outcome6_3a5
			
		reg el_index_p_gender $nocontrols
		eststo outcome6_3a6
			
		reg el_index_p_schooling $nocontrols
		eststo outcome6_3a7
			
		reg el_index_p_marriage $nocontrols
		eststo outcome6_3a8
		
		reg el_index_locus_control $nocontrols
		eststo outcome6_3a9
		
		reg el_index_stress $nocontrols
		eststo outcome6_3a10
		
		reg el_index_rosenberg $nocontrols
		eststo outcome6_3a11

		esttab outcome6_3a1 outcome6_3a2 outcome6_3a3 outcome6_3a5 outcome6_3a6 outcome6_3a7 outcome6_3a8 outcome6_3a9 outcome6_3a10 outcome6_3a11 using "$tables/table6/table6_3_A.csv", ar2 se(%9.3f) b(%9.3f) noconstant varwidth(30) nogaps compress label keep(treat) replace star(* 0.10 ** 0.05 *** 0.01)

		** Panel B
		reg el_index_p_strengths bl_index_p_strengths mis_bl_index_p_strengths $basiccontrols
		eststo outcome6_3b1
			
		reg el_index_p_efficacy bl_index_p_efficacy mis_bl_index_p_efficacy $basiccontrols
		eststo outcome6_3b2
		
		reg el_index_p_movement1 bl_index_p_movement1 mis_bl_index_p_movement1 $basiccontrols
		eststo outcome6_3b3
		
		reg el_index_p_communication bl_index_p_communication mis_bl_index_p_communication $basiccontrols
		eststo outcome6_3b5
			
		reg el_index_p_gender bl_index_p_gender mis_bl_index_p_gender $basiccontrols
		eststo outcome6_3b6
			
		reg el_index_p_schooling bl_index_p_schooling mis_bl_index_p_schooling $basiccontrols
		eststo outcome6_3b7
			
		reg el_index_p_marriage bl_index_p_marriage mis_bl_index_p_marriage $basiccontrols
		eststo outcome6_3b8
		
		reg el_index_locus_control $additionalcontrols $basiccontrols
		eststo outcome6_3b9
		
		reg el_index_stress $additionalcontrols $basiccontrols
		eststo outcome6_3b10
		
		reg el_index_rosenberg $additionalcontrols $basiccontrols
		eststo outcome6_3b11

		esttab outcome6_3b1 outcome6_3b2 outcome6_3b3 outcome6_3b5 outcome6_3b6 outcome6_3b7 outcome6_3b8 outcome6_3b9 outcome6_3b10 outcome6_3b11 using "$tables/table6/table6_3_B.csv", ar2 se(%9.3f) b(%9.3f) noconstant varwidth(30) nogaps compress label keep(treat) replace star(* 0.10 ** 0.05 *** 0.01)

		** Panel C
		reg el_index_p_strengths $imbalancecontrols bl_index_p_strengths mis_bl_index_p_strengths $basiccontrols
		eststo outcome6_3c1
			
		reg el_index_p_efficacy $imbalancecontrols bl_index_p_efficacy mis_bl_index_p_efficacy $basiccontrols
		eststo outcome6_3c2
		
		reg el_index_p_movement1 $imbalancecontrols bl_index_p_movement1 mis_bl_index_p_movement1 $basiccontrols
		eststo outcome6_3c3
		
		reg el_index_p_communication $imbalancecontrols bl_index_p_communication mis_bl_index_p_communication $basiccontrols
		eststo outcome6_3c5
			 
		reg el_index_p_gender $imbalancecontrols bl_index_p_gender mis_bl_index_p_gender $basiccontrols
		eststo outcome6_3c6
			
		reg el_index_p_schooling $imbalancecontrols bl_index_p_schooling mis_bl_index_p_schooling $basiccontrols
		eststo outcome6_3c7
			
		reg el_index_p_marriage $imbalancecontrols bl_index_p_marriage mis_bl_index_p_marriage $basiccontrols
		eststo outcome6_3c8
		
		reg el_index_locus_control $imbalancecontrols $additionalcontrols $basiccontrols
		eststo outcome6_3c9
		
		reg el_index_stress $imbalancecontrols $additionalcontrols $basiccontrols
		eststo outcome6_3c10 
		 
		reg el_index_rosenberg $imbalancecontrols $additionalcontrols $basiccontrols
		eststo outcome6_3c11

		esttab outcome6_3c1 outcome6_3c2 outcome6_3c3 outcome6_3c5 outcome6_3c6 outcome6_3c7 outcome6_3c8 outcome6_3c9 outcome6_3c10 outcome6_3c11 using "$tables/table6/table6_3_C.csv", ar2 se(%9.3f) b(%9.3f) noconstant varwidth(30) nogaps compress label keep(treat) replace star(* 0.10 ** 0.05 *** 0.01)
	
		eststo drop outcome6_3*
		
		
		** Table 10: heterogeneous effects
		** Table 10-1
		
		reg el_index_delay $het1controls
		eststo outcome10_1a_1
			
		reg el_index_attempts $het1controls
		eststo outcome10_1a_2
		
		reg el_index_time $het1controls
		eststo outcome10_1a_3
		
		reg el_index_scavenger $het1controls
		eststo outcome10_1a_4
	
	** School quality
	
		reg el_index_delay $het2controls
		eststo outcome10_1b_1
			
		reg el_index_attempts $het2controls
		eststo outcome10_1b_2
		
		reg el_index_time $het2controls
		eststo outcome10_1b_3
		
		reg el_index_scavenger $het2controls
		eststo outcome10_1b_4
	
	
	** age
	
		reg el_index_delay $het3controls
		eststo outcome10_1c_1
			
		reg el_index_attempts $het3controls
		eststo outcome10_1c_2
		
		reg el_index_time $het3controls
		eststo outcome10_1c_3
		
		reg el_index_scavenger $het3controls
		eststo outcome10_1c_4
		
	** economic shock
	
		reg el_index_delay $het4controls
		eststo outcome10_1d_1
			
		reg el_index_attempts $het4controls
		eststo outcome10_1d_2
		
		reg el_index_time $het4controls
		eststo outcome10_1d_3
		
		reg el_index_scavenger $het4controls
		eststo outcome10_1d_4
		
	** death/illness shock
	
		reg el_index_delay $het5controls
		eststo outcome10_1e_1
			
		reg el_index_attempts $het5controls
		eststo outcome10_1e_2
		
		reg el_index_time $het5controls
		eststo outcome10_1e_3
		
		reg el_index_scavenger $het5controls
		eststo outcome10_1e_4
				
	** crime/dispute shock
	
		reg el_index_delay $het6controls
		eststo outcome10_1f_1
			
		reg el_index_attempts $het6controls
		eststo outcome10_1f_2
		
		reg el_index_time $het6controls
		eststo outcome10_1f_3
		
		reg el_index_scavenger $het6controls
		eststo outcome10_1f_4
		
		esttab outcome10_1a_1 outcome10_1a_2 outcome10_1a_3 outcome10_1a_4 outcome10_1b_1 outcome10_1b_2 outcome10_1b_3 outcome10_1b_4 outcome10_1c_1 outcome10_1c_2 outcome10_1c_3 outcome10_1c_4  outcome10_1d_1 outcome10_1d_2 outcome10_1d_3 outcome10_1d_4 outcome10_1e_1 outcome10_1e_2 outcome10_1e_3 outcome10_1e_4  outcome10_1f_1 outcome10_1f_2 outcome10_1f_3 outcome10_1f_4 using "$tables/heterogeneous_effects/table10_1.csv", ar2 se(%9.3f) b(%9.3f) noconstant varwidth(30) nogaps compress label keep(treat*) replace star(* 0.10 ** 0.05 *** 0.01)
		
		eststo drop outcome10_1*
			
	** Table 10-2
		
	** Mother's education
		
		reg el_index_marriage $het1controls
		eststo outcome10_2a_1
			
		reg el_index_socioemotional $het1controls
		eststo outcome10_2a_2
		
		reg el_index_movement1 $het1controls
		eststo outcome10_2a_3
		
		reg el_index_empowerment $het1controls
		eststo outcome10_2a_5
			
		reg el_index_selfesteem $het1controls
		eststo outcome10_2a_6
			
		reg el_index_planning $het1controls
		eststo outcome10_2a_7
		
		reg el_index_marr_expect $het1controls
		eststo outcome10_2a_8
		
		reg el_index_employ $het1controls
		eststo outcome10_2a_9
		
		reg el_index_gender $het1controls
		eststo outcome10_2a_10
		
		reg el_index_cantrill $het1controls
		eststo outcome10_2a_11
		
		reg el_index_enumerator $het1controls
		eststo outcome10_2a_12
	
	** School quality
	
		reg el_index_marriage $het2controls
		eststo outcome10_2b_1
			
		reg el_index_socioemotional $het2controls
		eststo outcome10_2b_2
		
		reg el_index_movement1 $het2controls
		eststo outcome10_2b_3

		reg el_index_empowerment $het2controls
		eststo outcome10_2b_5
			
		reg el_index_selfesteem $het2controls
		eststo outcome10_2b_6
			
		reg el_index_planning $het2controls
		eststo outcome10_2b_7
		
		reg el_index_marr_expect $het2controls
		eststo outcome10_2b_8
		
		reg el_index_employ $het2controls
		eststo outcome10_2b_9
		
		reg el_index_gender $het2controls
		eststo outcome10_2b_10
		
		reg el_index_cantrill $het2controls
		eststo outcome10_2b_11
		
		reg el_index_enumerator $het2controls
		eststo outcome10_2b_12
	
	
	** age
	
		reg el_index_marriage $het3controls
		eststo outcome10_2c_1
			
		reg el_index_socioemotional $het3controls
		eststo outcome10_2c_2
		
		reg el_index_movement1 $het3controls
		eststo outcome10_2c_3
		
		reg el_index_empowerment $het3controls
		eststo outcome10_2c_5
			
		reg el_index_selfesteem $het3controls
		eststo outcome10_2c_6
			
		reg el_index_planning $het3controls
		eststo outcome10_2c_7
		
		reg el_index_marr_expect $het3controls
		eststo outcome10_2c_8
		
		reg el_index_employ $het3controls
		eststo outcome10_2c_9
		
		reg el_index_gender $het3controls
		eststo outcome10_2c_10
		
		reg el_index_cantrill $het3controls
		eststo outcome10_2c_11
		
		reg el_index_enumerator $het3controls
		eststo outcome10_2c_12
		
	** economic shock
	
		reg el_index_marriage $het4controls
		eststo outcome10_2d_1
			
		reg el_index_socioemotional $het4controls
		eststo outcome10_2d_2
		
		reg el_index_movement1 $het4controls
		eststo outcome10_2d_3
		
		reg el_index_empowerment $het4controls
		eststo outcome10_2d_5
			
		reg el_index_selfesteem $het4controls
		eststo outcome10_2d_6
			
		reg el_index_planning $het4controls
		eststo outcome10_2d_7
		
		reg el_index_marr_expect $het4controls
		eststo outcome10_2d_8
		
		reg el_index_employ $het4controls
		eststo outcome10_2d_9
		
		reg el_index_gender $het4controls
		eststo outcome10_2d_10
		
		reg el_index_cantrill $het4controls
		eststo outcome10_2d_11
		
		reg el_index_enumerator $het4controls
		eststo outcome10_2d_12
		
	** death/illness shock
	
		reg el_index_marriage $het5controls
		eststo outcome10_2e_1
			
		reg el_index_socioemotional $het5controls
		eststo outcome10_2e_2
		
		reg el_index_movement1 $het5controls
		eststo outcome10_2e_3
		
		reg el_index_empowerment $het5controls
		eststo outcome10_2e_5
			
		reg el_index_selfesteem $het5controls
		eststo outcome10_2e_6
			
		reg el_index_planning $het5controls
		eststo outcome10_2e_7
		
		reg el_index_marr_expect $het5controls
		eststo outcome10_2e_8
		
		reg el_index_employ $het5controls
		eststo outcome10_2e_9
		
		reg el_index_gender $het5controls
		eststo outcome10_2e_10
		
		reg el_index_cantrill $het5controls
		eststo outcome10_2e_11
		
		reg el_index_enumerator $het5controls
		eststo outcome10_2e_12
				
	** crime/dispute shock
	
		reg el_index_marriage $het6controls
		eststo outcome10_2f_1
			
		reg el_index_socioemotional $het6controls
		eststo outcome10_2f_2
		
		reg el_index_movement1 $het6controls
		eststo outcome10_2f_3

		reg el_index_empowerment $het6controls
		eststo outcome10_2f_5
			
		reg el_index_selfesteem $het6controls
		eststo outcome10_2f_6
			
		reg el_index_planning $het6controls
		eststo outcome10_2f_7
		
		reg el_index_marr_expect $het6controls
		eststo outcome10_2f_8
		
		reg el_index_employ $het6controls
		eststo outcome10_2f_9
		
		reg el_index_gender $het6controls
		eststo outcome10_2f_10
		
		reg el_index_cantrill $het6controls
		eststo outcome10_2f_11
		
		reg el_index_enumerator $het6controls
		eststo outcome10_2f_12
		
		esttab outcome10_2a_1 outcome10_2a_2 outcome10_2a_3 outcome10_2a_5 outcome10_2a_6 outcome10_2a_7 outcome10_2a_8 outcome10_2a_9 outcome10_2a_10 outcome10_2a_11 outcome10_2a_12 outcome10_2b_1 outcome10_2b_2 outcome10_2b_3 outcome10_2b_5 outcome10_2b_6 outcome10_2b_7 outcome10_2b_8 outcome10_2b_9 outcome10_2b_10 outcome10_2b_11 outcome10_2b_12 outcome10_2c_1 outcome10_2c_2 outcome10_2c_3 outcome10_2c_5 outcome10_2c_6 outcome10_2c_7 outcome10_2c_8 outcome10_2c_9 outcome10_2c_10 outcome10_2c_11 outcome10_2c_12 outcome10_2d_1 outcome10_2d_2 outcome10_2d_3 outcome10_2d_5 outcome10_2d_6 outcome10_2d_7 outcome10_2d_8 outcome10_2d_9 outcome10_2d_10 outcome10_2d_11 outcome10_2d_12 outcome10_2e_1 outcome10_2e_2 outcome10_2e_3 outcome10_2e_5 outcome10_2e_6 outcome10_2e_7 outcome10_2e_8 outcome10_2e_9 outcome10_2e_10 outcome10_2e_11 outcome10_2e_12 outcome10_2f_1 outcome10_2f_2 outcome10_2f_3 outcome10_2f_5 outcome10_2f_6 outcome10_2f_7 outcome10_2f_8 outcome10_2f_9 outcome10_2f_10 outcome10_2f_11 outcome10_2f_12 using "$tables/heterogeneous_effects/table10_2.csv", ar2 se(%9.3f) b(%9.3f) noconstant varwidth(30) nogaps compress label keep(treat*) replace star(* 0.10 ** 0.05 *** 0.01)
		eststo drop outcome10_2*
		
		** Table 10-3
		
	** Mother's education
		
		reg el_index_p_strengths $het1controls
		eststo outcome10_3a_1
			
		reg el_index_p_efficacy $het1controls
		eststo outcome10_3a_2
		
		reg el_index_p_movement1 $het1controls
		eststo outcome10_3a_3
		
		reg el_index_p_communication $het1controls
		eststo outcome10_3a_5
			
		reg el_index_p_gender $het1controls
		eststo outcome10_3a_6
			
		reg el_index_p_schooling $het1controls
		eststo outcome10_3a_7
		
		reg el_index_p_marriage $het1controls
		eststo outcome10_3a_8
		
		reg el_index_locus_control $het1controls
		eststo outcome10_3a_9
		
		reg el_index_stress $het1controls
		eststo outcome10_3a_10
		
		reg el_index_rosenberg $het1controls
		eststo outcome10_3a_11
		
		** school quality
		
		reg el_index_p_strengths $het2controls
		eststo outcome10_3b_1
			
		reg el_index_p_efficacy $het2controls
		eststo outcome10_3b_2
		
		reg el_index_p_movement1 $het2controls
		eststo outcome10_3b_3

		reg el_index_p_communication $het2controls
		eststo outcome10_3b_5
			
		reg el_index_p_gender $het2controls
		eststo outcome10_3b_6
			
		reg el_index_p_schooling $het2controls
		eststo outcome10_3b_7
		
		reg el_index_p_marriage $het2controls
		eststo outcome10_3b_8
		
		reg el_index_locus_control $het2controls
		eststo outcome10_3b_9
		
		reg el_index_stress $het2controls
		eststo outcome10_3b_10
		
		reg el_index_rosenberg $het2controls
		eststo outcome10_3b_11
		
		** age
		
		reg el_index_p_strengths $het3controls
		eststo outcome10_3c_1
			
		reg el_index_p_efficacy $het3controls
		eststo outcome10_3c_2
		
		reg el_index_p_movement1 $het3controls
		eststo outcome10_3c_3
		
		reg el_index_p_communication $het3controls
		eststo outcome10_3c_5
			
		reg el_index_p_gender $het3controls
		eststo outcome10_3c_6
			
		reg el_index_p_schooling $het3controls
		eststo outcome10_3c_7
		
		reg el_index_p_marriage $het3controls
		eststo outcome10_3c_8
		
		reg el_index_locus_control $het3controls
		eststo outcome10_3c_9
		
		reg el_index_stress $het3controls
		eststo outcome10_3c_10
		
		reg el_index_rosenberg $het3controls
		eststo outcome10_3c_11
		
		** economic shock
		
		reg el_index_p_strengths $het4controls
		eststo outcome10_3d_1
			
		reg el_index_p_efficacy $het4controls
		eststo outcome10_3d_2
		
		reg el_index_p_movement1 $het4controls
		eststo outcome10_3d_3

		reg el_index_p_communication $het4controls
		eststo outcome10_3d_5
			
		reg el_index_p_gender $het4controls
		eststo outcome10_3d_6
			
		reg el_index_p_schooling $het4controls
		eststo outcome10_3d_7
		
		reg el_index_p_marriage $het4controls
		eststo outcome10_3d_8
		
		reg el_index_locus_control $het4controls
		eststo outcome10_3d_9
		
		reg el_index_stress $het4controls
		eststo outcome10_3d_10
		
		reg el_index_rosenberg $het4controls
		eststo outcome10_3d_11
		
		** death/illness
		
		reg el_index_p_strengths $het5controls
		eststo outcome10_3e_1
			
		reg el_index_p_efficacy $het5controls
		eststo outcome10_3e_2
		
		reg el_index_p_movement1 $het5controls
		eststo outcome10_3e_3
		
		reg el_index_p_communication $het5controls
		eststo outcome10_3e_5
			
		reg el_index_p_gender $het5controls
		eststo outcome10_3e_6
			
		reg el_index_p_schooling $het5controls
		eststo outcome10_3e_7
		
		reg el_index_p_marriage $het5controls
		eststo outcome10_3e_8
		
		reg el_index_locus_control $het5controls
		eststo outcome10_3e_9
		
		reg el_index_stress $het5controls
		eststo outcome10_3e_10
		
		reg el_index_rosenberg $het5controls
		eststo outcome10_3e_11
		
		** crime/dispute
		
		reg el_index_p_strengths $het6controls
		eststo outcome10_3f_1
			
		reg el_index_p_efficacy $het6controls
		eststo outcome10_3f_2
		
		reg el_index_p_movement1 $het6controls
		eststo outcome10_3f_3
		
		reg el_index_p_communication $het6controls
		eststo outcome10_3f_5
			
		reg el_index_p_gender $het6controls
		eststo outcome10_3f_6
			
		reg el_index_p_schooling $het6controls
		eststo outcome10_3f_7
		
		reg el_index_p_marriage $het6controls
		eststo outcome10_3f_8
		
		reg el_index_locus_control $het6controls
		eststo outcome10_3f_9
		
		reg el_index_stress $het6controls
		eststo outcome10_3f_10
		
		reg el_index_rosenberg $het6controls
		eststo outcome10_3f_11
		
		esttab outcome10_3a_1 outcome10_3a_2 outcome10_3a_3 outcome10_3a_5 outcome10_3a_6 outcome10_3a_7 outcome10_3a_8 outcome10_3a_9 outcome10_3a_10 outcome10_3a_11 outcome10_3b_1 outcome10_3b_2 outcome10_3b_3 outcome10_3b_5 outcome10_3b_6 outcome10_3b_7 outcome10_3b_8 outcome10_3b_9 outcome10_3b_10 outcome10_3b_11 outcome10_3c_1 outcome10_3c_2 outcome10_3c_3 outcome10_3c_5 outcome10_3c_6 outcome10_3c_7 outcome10_3c_8 outcome10_3c_9 outcome10_3c_10 outcome10_3c_11 outcome10_3d_1 outcome10_3d_2 outcome10_3d_3 outcome10_3d_5 outcome10_3d_6 outcome10_3d_7 outcome10_3d_8 outcome10_3d_9 outcome10_3d_10 outcome10_3d_11 outcome10_3e_1 outcome10_3e_2 outcome10_3e_3 outcome10_3e_5 outcome10_3e_6 outcome10_3e_7 outcome10_3e_8 outcome10_3e_9 outcome10_3e_10 outcome10_3e_11 outcome10_3f_1 outcome10_3f_2 outcome10_3f_3 outcome10_3f_5 outcome10_3f_6 outcome10_3f_7 outcome10_3f_8 outcome10_3f_9 outcome10_3f_10 outcome10_3f_11 using "$tables/heterogeneous_effects/table10_3.csv", ar2 se(%9.3f) b(%9.3f) noconstant varwidth(30) nogaps compress label keep(treat*) replace star(* 0.10 ** 0.05 *** 0.01)
		eststo drop outcome10_3*
		

